@@ -71,7 +71,7 @@ class MDS:
             raise InvalidParamsError(param_name="data_type", param_value=data_type)
 
         try:
-            self.get_dataset(name)
+            self._x_api.get_dataset_name(name)
             raise NameConflictError(resource="dataset", identification=name)
         except ResourceNotExistError:
             pass
